==> supply-chain-basic-api-1.1.5-20200914.070000-1-sources.jar: com/rocogz/supplychain/api/entity/supplychain/SupplierProduct.java <==
package com.rocogz.supplychain.api.entity.supplychain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.rocogz.common.api.constant.FormatConstant;
import lombok.Data;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * @author Andrew
 * @create 2020/2/19 10:56 上午
 */

@Data
@Table(name = "sc_supplier_product")
public class SupplierProduct implements Serializable {

    @Id
    private Long id;

    /**
     * 编码
     */
    private String code;

    /**
     * 上游产品编码
     */
    private String upstreamCode;

    /**
     * 名称
     */
    private String name;

    /**
     *  拼音
     */
    private String pinyin;

    /**
     * 简称
     */
    private String simpleName;

    /**
     * 类目编码
     */
    private String catalogCode;

    /**
     * 分类名称
     */
    private String catalogName;

    /**
     * 品牌编码
     */
    private String brandCode;

    /**
     * 品牌名称
     */
    private String brandName;

    /**
     * 产品摘要
     */
    private String productBrief;

    /**
     * 供应商渠道名称
     */
    private String channelName;

    /**
     * 供应商渠道编号
     */
    private String channelCode;

    /**
     * 上游渠道商编码
     */
    private String supplierNo;

    /**
     * 上游渠道商名称
     */
    private String supplierName;

    /**
     *  上游渠道商备付金账户编码
     */
    private String acctCode;

    /**
     *  账户名称
     */
    private String acctName;

    /**
     * 产品面值
     */
    private BigDecimal price;
    /**
     * 产品采购价
     */
    private BigDecimal purchasePrice;
    /**
     * 产品销售价
     */
    private BigDecimal sellPrice;

    /**
     * 充值折扣
     */
    private BigDecimal discount;
    /**
     * 状态(1启用,0停用)
     */
    private Integer status;
    /**
     * 说明
     */
    private String remark;

    /**
     * OIL_CARD 油卡产品,THIRD第三方产品
     */
    private String nature;

    private String createUser;

    private String createName;

    @JsonFormat(pattern = FormatConstant.YYYY_MM_DD_HH_MM_SS, timezone = FormatConstant.TIME_ZONE)
    private LocalDateTime createTime;

    private String createUsertype;

    private String updateUser;

    @JsonFormat(pattern = FormatConstant.YYYY_MM_DD_HH_MM_SS, timezone = FormatConstant.TIME_ZONE)
    private LocalDateTime updateTime;

    private String updateUsertype;

    private String updateName;

}

==> supply-chain-basic-api-1.1.5-20200923.052132-2-sources.jar: com/rocogz/supplychain/api/entity/supplychain/SupplierProduct.java <==
package com.rocogz.supplychain.api.entity.supplychain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.rocogz.common.api.constant.FormatConstant;
import lombok.Data;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * @author Andrew
 * @create 2020/2/19 10:56 上午
 */

@Data
@Table(name = "sc_supplier_product")
public class SupplierProduct implements Serializable {

    @Id
    private Long id;

    /**
     * 编码
     */
    private String code;

    /**
     * 上游产品编码
     */
//    private String upstreamCode;

    /**
     * 名称
     */
    private String name;

    /**
     *  拼音
     */
    private String pinyin;

    /**
     * 简称
     */
    private String simpleName;

    /**
     * 类目编码
     */
    private String catalogCode;

    /**
     * 分类名称
     */
    private String catalogName;

    /**
     * 品牌编码
     */
    private String brandCode;

    /**
     * 品牌名称
     */
    private String brandName;

    /**
     * 产品摘要
     */
//    private String productBrief;

    /**
     * 供应商渠道名称
     */
//    private String channelName;

    /**
     * 供应商渠道编号
     */
//    private String channelCode;

    /**
     * 上游渠道商编码
     */
    private String supplierNo;

    /**
     * 上游渠道商名称
     */
    private String supplierName;

    /**
     *  上游渠道商备付金账户编码
     */
    private String acctCode;

    /**
     *  账户名称
     */
    private String acctName;

    /**
     * 产品面值
     */
    private BigDecimal price;
    /**
     * 产品采购价
     */
    private BigDecimal purchasePrice;
    /**
     * 产品销售价
     */
//    private BigDecimal sellPrice;

    /**
     * 充值折扣
     */
//    private BigDecimal discount;
    /**
     * 状态(1启用,0停用)
     */
    private Integer status;
    /**
     * 说明
     */
    private String remark;

    /**
     * OIL_CARD 油卡产品,THIRD第三方产品
     */
//    private String nature;

    private String createUser;

    private String createName;

    @JsonFormat(pattern = FormatConstant.YYYY_MM_DD_HH_MM_SS, timezone = FormatConstant.TIME_ZONE)
    private LocalDateTime createTime;

    private String createUsertype;

    private String updateUser;

    @JsonFormat(pattern = FormatConstant.YYYY_MM_DD_HH_MM_SS, timezone = FormatConstant.TIME_ZONE)
    private LocalDateTime updateTime;

    private String updateUsertype;

    private String updateName;

    /**
     * 是否关联备付金
     */
    private Integer isRelateDeposit;
    
    private String channelProductType;
    
    private String channelProductCode;
    

}
